codec_utils_vpx_create_vpcc_from_caps

Function codec_utils_vpx_create_vpcc_from_caps 

pub fn codec_utils_vpx_create_vpcc_from_caps(caps: &CapsRef) -> Option<Buffer>
Creates a vpcC record for VP8/VP9 as per the VP Codec ISO Media File Format Binding definition found at https://www.webmproject.org/vp9/mp4/vp-codec-configuration-box

caps

a video/x-vp8 or video/x-vp9 gst::Caps

Returns

Buffer containing the vpcC record, or None if the record could not be created.